﻿using Infragistics.UltraChart.Core;
using Infragistics.UltraChart.Core.Layers;
using Infragistics.UltraChart.Resources.Appearance;
using Infragistics.UltraChart.Shared.Styles;
using Infragistics.Win.UltraWinChart;
using System;
using System.Collections.Generic;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace WC_GanttChartSplitter
{

    public class MovingAxisTool : InteractionTool
    {
        private const int size = 4;
        private Point prevPoint;

        /// <summary>

        /// Initializes a new instance of the <see cref="MovingAxisTool"/> class.

        /// </summary>

        /// <param name="ultraChart">The ultra chart.</param>

        public MovingAxisTool(UltraChart ultraChart)
            : base(ultraChart)
        {
            
        }

        /// <summary>

        /// Determines whether this tool can start.

        /// </summary>

        /// <returns>

        /// <c>true</c> if this tool can start; otherwise, <c>false</c>.

        /// </returns>

        public override bool CanStart()
        {

            ChartLayer chartLayer = this.ChartCore.GetChartLayer();
            IAdvanceAxis axisX = chartLayer.Grid["X"] as IAdvanceAxis;
            IAdvanceAxis axisY = chartLayer.Grid["Y"] as IAdvanceAxis;

            this.prevPoint = this.LastInput.ViewPoint;

            if (Math.Abs(this.prevPoint.X - (double)axisX.MapMinimum) < size
                && axisY.MapMaximum < prevPoint.Y && axisY.MapMinimum > prevPoint.Y)
            {

                return true;
            }

            return false;
        }

        public override void Start()
        {

            base.Start(); 
            Cursor.Current = Cursors.SizeWE;
        }



        /// <summary>
        /// Called when this tool is started and the mouse is moved.
        /// </summary>

        public override void MouseMove()
        {

            base.MouseMove();


            int dx = prevPoint.X - this.LastInput.ViewPoint.X;
            int newExtend = this.UltraChart.Axis.Y.Extent - dx;

            if (newExtend < 0)
            {

                newExtend = 0;

            }

            if (newExtend > 500)
            {

                newExtend = 500;

            }

            this.UltraChart.Axis.Y.Extent = newExtend;
            this.prevPoint = this.LastInput.ViewPoint;

            this.InvalidateView(CacheLevel.ImageLevelCache);
        }



        /// <summary>
        /// Called when this tool stops.
        /// </summary>

        public override void Stop()
        {

            System.Windows.Forms.Cursor.Current = Cursors.Default; 
            base.Stop();
        }

       

      



    } 


}
